﻿using DemoApp.Filters;
using System;
using System.Collections.Generic;
using System.Diagnostics;
using System.Drawing;
using System.IO;
using System.Threading.Tasks;

namespace DemoApp.Parallelization
{
    class Program
    {
        static void Main(string[] args)
        {
            // Path of sample images
            string imagesPath = @"..\..\images";

            // Get the maximum degree of parallelism (i.e. the max. number of threads)
            Console.Write("Max. degree of parallelism: ");
            int degreeOfParallelism = Int32.Parse(Console.ReadLine());

            // Load images into a list
            List<Bitmap> images = new List<Bitmap>();
            foreach (FileInfo fi in new DirectoryInfo(imagesPath).EnumerateFiles("*.jpg"))
            {
                images.Add(new Bitmap(fi.FullName));
            }

            // Start parallel processing
            Parallel.ForEach(
                images, // Do the processing on the list of images
                new ParallelOptions { MaxDegreeOfParallelism = degreeOfParallelism }, // Set the max. number of threads
                image => { new FloydSteinbergDitherColorFilter(2).ApplyInPlace(image); } // Apply the filter on each image
                );

            // Finished
            Console.WriteLine("Done!");
        }

    }
}
